cloudPath = "~/Nextcloud/ComparisonCSOMs/"
fsolPath = paste(cloudPath,"ecoli_core_itacon/",sep = "")

library(ggplot2)
library(reshape2)
library(plyr)
library(dplyr)
library(gplots)
library(biclust)


setwd(cloudPath)
source("Analysis/metricsFunctions.R")
source("Analysis/pathwayFunctions.R")
source("ASAP/solutionFunctions.R")

metricsID = "_MetricsOverview_[ATPMopen].csv"

metricsNames = c("Product FVA minimum (1% growth)", "Product FVA minimum (90% growth)", "Maximum growth rate" ,"BPCY", "Carbon yield (P/S)", "Size","Algorithm")
algorithms = c("MCS_ATP","MCS_FIXED")

ds = lapply(algorithms, function(x){readDf(paste(fsolPath, x,metricsID, sep = ""), x)})
dsa = subset(do.call(rbind, ds), select = c(-Size))
dsa$X.BiomassSynthesis.ITA_EX..GLC_UP = abs(dsa$X.BiomassSynthesis.ITA_EX..GLC_UP)
dsa = dsa[which(dsa$FVAmin.ITA_EX...1..biomass > 0),]
names(dsa) = metricsNames

mb = metricsBoxplot(dsa, 2, 3)
fq = read.csv(paste(fsolPath,"RxFrequency.csv",sep="/"), row.names = 1)
fq2 = read.csv(paste(fsolPath,"RxFrequency2.csv",sep="/"), row.names = 1)
fq3 = read.csv(paste(fsolPath,"RxFrequency3.csv",sep="/"), row.names = 1)

fh = frequencyHeatmap(fq, "white", "blue", thres = 0.08)
fh
fh2 = frequencyHeatmap(fq2, "white", "blue", thres = 0.1)
fh3 = frequencyHeatmap(fq3, "white", "blue", thres = 0.06)

fd = lapply(algorithms, function(x){readDf(paste(fsolPath,x,"_pFBA",".csv",sep = ""),x)})
fda = do.call(rbind,fd)
fda$Size = as.integer(fda$Size)
fda$Algorithm = as.character(fda$Algorithm)

fdAb = abs(fda %>% select_if(function(x){is.numeric(x) && !is.integer(x)}))
fdr = sapply(algorithms, function(x){apply(fdAb[fda$Algorithm == x,], 2, mean)})
fdr = as.data.frame(fdr)
bmss = union(grep("_Synth",row.names(fdr)),grep("_UP",row.names(fdr)))
bmss = union(bmss, grep("_synth",row.names(fdr)))
fdr = fdr[-bmss,]
fdrn = apply(fdr, 1, function(x){x/mean(x)})
fdrna = t(na.exclude(t(fdrn)))
fdrna = fdrna[hclust(dist(fdrna))$order,hclust(dist(t(fdrna)))$order]
mlt = melt(data = fdrna, varnames = c("Algorithm","Reaction"), value.name = "Average")
htm = ggplot(mlt) +
  geom_tile(mapping = aes(x = Algorithm, y = Reaction, fill = Average)) +
  theme_classic() +
  textSlant(60,10) +
  scale_fill_gradient2(midpoint = 1, low = "blue", mid = "white", high = "red")


saveFunction = function(plot, name){ggsave(filename = paste(fsolPath,name,".pdf",sep=""), plot = plot, device = pdf, width = 4, height = 9)}

saveFunction(htm, "FluxHeatmap")
saveFunction(mb, "MetricsBoxplot")
saveFunction(fh, "FrequencyHeatmap")
saveFunction(fh2, "FrequencyHeatmap2")
saveFunction(fh3, "FrequencyHeatmap3")
